% Chapter 1 Exercise 1.b
% Analysis of the standard deviation
%
%
% Copyright: 
% Johan Schoukens, Rik Pintelon, and Yves Rolain 
% Vrije Universiteit Brussels, Pleinlaan 2, 1050 Brussels, Belgium
%
% 23 November 2010

clear all

% define the input variables 

NRepeat=1000                % Number of repeated experiments
NData=[10 100 1000 10000 100000]   % number of measurements in 1 experiment
iMax=0.1                   % maximum amplitude of the current
stdU=1                      % std. dev. disturbing noise
stdI=.01                   % std. dev. disturbing noise
R0=20                     % exact value resistor

for r=1:length(NData)       % run over the different data lengths
	for k=1:NRepeat         % run over the repeated experiments
        i1=iMax*ones(NData(r),1);    % generate constant current
        i=i1+stdI*randn(size(i1));    % generate constant current
        u=R0*i1+stdU*randn(size(i)); % generate disturbed output
                %uU=R0*i+stdU*(rand(size(i))-0.5)*2*sqrt(3);     % generate uniformly disturbed output
        R(k,r)=u'*i/(i'*i); % calculate the LS-estimate
        %R(k,r)=mean(u./i); % calculate the LS-estimate
        %R(k,r)=mean(u)/mean(i); % calculate the LS-estimate
	end
end

bR2=(mean(R,1)-R0).^2;
VR=std(R,0,1).^2;     % calculate standard deviation

% Plot the results

FigNum=2;

figure(FigNum)
clf
     
K=logspace(1,log10(NData(end)),100);
VRU=stdU^2./(K.*iMax^2);
VRUI=R0^2*(stdU^2/(R0*iMax)^2+stdI^2/iMax^2)./NData;
loglog(K,VRU,'.k',NData,VRUI,'ok',NData,VRUI+bR2,'*k') 
title('Standard deviation R(N)')
xlabel('N')
ylabel('std Rest')
DG_SetFontSize(12)
DG_SetTraceTint(30,1,FigNum,1)
DG_SetTraceWidth(3,1,FigNum,1)

% Export the figure
% DG_Init4PDF(gcf, 6);                                   % fixing the size
% DG_MakePDF('FigIdent2.pdf', gcf);

